MSP430 Housekeeping Example - Generating a Large Number of PWMs

## Example Summary

This GUI allows interaction with a MSP430FR2476 LaunchPad to generate a large number of independent pulse width modulation (PWM) outputs on the microcontroller and display the PWMs on the GUI.

Using the drop-downs, the timer and capture/compare registers can be changed. Drop-downs can also be used to change the duty cycle and frequency of PWMs output from these timer modules. While the duty-cycle and frequency drop-downs are being changed, the corresponding LED on the GUI will turn off. Once the PLOT button is clicked for a specific plot, the corresponding LED on the GUI will turn on, the corresponding plot on the GUI will be updated, and the appropriate PWM output from the microcontroller will change to match the duty-cycle and frequency chosen. 

The GUI is available at [Generating a Large Number of Independent PWMs](add link here).
The GUI project is also included as a ZIP file and can be imported to [GUI Composer](https://dev.ti.com/gc/).

## Peripherals & Pin Assignments
```
P5.3 --> TA3.0 (PWM)
P4.6 --> TA3.1 (PWM)
P4.5 --> TA3.2 (PWM)
P6.2 --> TB0.0 (PWM)
P4.7 --> TB0.1 (PWM)
P5.0 --> TB0.2 (PWM)
P5.1 --> TB0.3 (PWM)
P5.2 --> TB0.4 (PWM)
P4.3 --> TB0.5 (PWM)
P4.4 --> TB0.6 (PWM)
P1.4 --> eUSCI_A0 UART TX
P1.5 <-- eUSCI_A0 UART RX
```
All other pins are initialized as output low to reduce power consumption.

## Clock configuration

* ACLK = default, REFO ~32768Hz
* MCLK = SMCLK = DCO = 16 MHz

## Board Resources & Jumper Settings

This example was developed and tested on MSP-EXP430FR2476.

* Jumper J101-GND: ON, Connects GND between the on-board debugger and LaunchPad
* Jumper J101-3V3: ON, Powers the LaunchPad through USB
* Jumper J101-RXD: ON, enables communication to back-channel UART
* Jumper J101-TXD: ON, enables communication to back-channel UART

## Example Usage

To get started:
* Connect the LaunchPad to your PC using the USB cable
* Identify the COM port for the MSP Application UART interface (found under “Ports” in Device Manager for Windows)

If using non-GUI (standalone) project:
* Open a serial terminal (PuTTY, Teraterm, etc) with the following settings:
```
    Baud-rate:		    9600
    Data bits:        	8
    Stop bits:        	1
    Parity:          	None
    Flow Control:    	None
```
* Type in any of the following keyboard keys to change the PWM output of a specific timer module and capture/compare register:
```
'a':    Choose to change Timer A3 CCR0
'b':    Choose to change Timer A3 CCR1
'c':    Choose to change Timer A3 CCR2
'd':    Choose to change Timer B0 CCR0
'e':    Choose to change Timer B0 CCR1
'f':    Choose to change Timer B0 CCR2
'g':    Choose to change Timer B0 CCR3
'h':    Choose to change Timer B0 CCR4
'i':    Choose to change Timer B0 CCR5
'j':    Choose to change Timer B0 CCR6
'k':    Increase duty cycle of chosen TxCCRn by 10%
'l':    Decrease duty cycle of chosen TxCCRn by 10%
'm':    Increase frequency of chosen TxCCRn by 500 Hz
'n':    Decrease frequency of chosen TxCCRn by 500 Hz
'o':    Type 'o', followed by a number (max 10 digits), followed by 'i' again. The frequency of the TxCCRn will be set to this value. *positive integer values only*
'p':    Type 'p', followed by a number (max 10 digits), followed by 'j' again. The duty cycle of the TxCCRn will be set to this value. *positive integer values only*
```

If using GUI project:
* Import the GUI to [GUI Composer](https://dev.ti.com/gc/) and execute it.
* Under “Options” > “Serial Port,” update the GUI Serial Port settings:
    ```
        Ports:			COM# for MSP Application UART
        Baud Rate:		115200
    ```
* Make sure the status at the bottom-left of the GUI shows “Hardware Connected.”
* Open the GUI project to see the output PWMs. Use dropdowns to change which PWM is being modified (change timer module and CCRs) and to change the PWM's duty-cycle and frequency.
     * Note: When using dropdowns to switch between Timer A3 and Timer B0 or the dropdowns to switch between CCRs on the “PWM Output 3” plot, the GUI will show that the frequency and duty-cycle have been reset to 1000 Hz and 20%, respectively. This might not be an accurate reflection of the PWMs output from the microcontroller if you have previously changed them.

Note:
  * By default, all PWMs output on the GUI and from the MSP430FR2476 will be at a 20% duty cycle and frequency of 1000 Hz. 
  * Optional: Connect the pins on the LaunchPad listed above to a logic analyzer to see the PWM outputs.

